@@ -41,16 +41,24 @@ sub _response_to_photos {
             api => $self->api,
             id => $_->{id},
             title => $_->{title},
-            date_upload => $_->{date_upload},
-            date_taken => $_->{date_taken},
+            date_upload => $_->{dateupload},
+            date_taken => $_->{datetaken},
             owner_id => $_->{owner},
-            owner_name => $_->{owner_name},
+            owner_name => $_->{ownername},
             url_s => $_->{url_s},
+            height_s => $_->{height_s},
+            width_s => $_->{width_s},
             url_m => $_->{url_m},
+            height_m => $_->{height_m},
+            width_m => $_->{width_m},
             url_l => $_->{url_l},
+            height_l => $_->{height_l},
+            width_l => $_->{width_l},
             url_o => $_->{url_o},
-            path_alias => $_->{path_alias},
-        )
+            height_o => $_->{height_o},
+            width_o => $_->{width_o},
+            path_alias => $_->{pathalias},
+        ),
     } @{ $photos->{photo} };
 
     return @photos;
